@@ -21,7 +21,7 @@ sub ProcessKodakPatch($$$);
 sub WriteUnknownOrPreview($$$);
 sub FixLeicaBase($$;$);
 
-$VERSION = '2.09';
+$VERSION = '2.11';
 
 my $debug;          # set to 1 to enable debugging code
 
@@ -570,6 +570,17 @@ my $debug;          # set to 1 to enable debugging code
             ByteOrder => 'Unknown',
         },
     },
+    {
+        Name => 'MakerNoteOlympus3',
+        # new Olympus maker notes start with "OLYMPUS\0"
+        Condition => '$$valPt =~ /^OM SYSTEM\0/',
+        SubDirectory => {
+            TagTable => 'Image::ExifTool::Olympus::Main',
+            Start => '$valuePtr + 16',
+            Base => '$start - 16',
+            ByteOrder => 'Unknown',
+        },
+    },
     {
         Name => 'MakerNoteLeica',
         # (starts with "LEICA\0\0\0")
@@ -691,7 +702,6 @@ my $debug;          # set to 1 to enable debugging code
         SubDirectory => {
             TagTable => 'Image::ExifTool::Panasonic::Leica9',
             Start => '$valuePtr + 8',
-            Base => '$start - 8',
             ByteOrder => 'Unknown',
         },
     },
@@ -1813,7 +1823,7 @@ maker notes in EXIF information.
 
 =head1 AUTHOR
 
-Copyright 2003-2020, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2022, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
