@@ -19,7 +19,7 @@ package Image::ExifTool::Shortcuts;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '1.65';
+$VERSION = '1.66';
 
 # this is a special table used to define command-line shortcuts
 # (documentation Notes may be added for these via %shortcutNotes in BuildTagLookup.pm)
@@ -158,6 +158,7 @@ $VERSION = '1.65';
         'MakerNoteNintendo',
         'MakerNoteOlympus',
         'MakerNoteOlympus2',
+        'MakerNoteOlympus3',
         'MakerNoteLeica',
         'MakerNoteLeica2',
         'MakerNoteLeica3',
@@ -265,6 +266,15 @@ $VERSION = '1.65';
         'XMP',
         'ZoomedPreviewImage',
     ],
+    'ls-l' => [
+        'FilePermissions',
+        'FileHardLinks',
+        'FileUserID',
+        'FileGroupID',
+        'FileSize#',
+        'FileModifyDate',
+        'FileName',
+    ],
 );
 
 #------------------------------------------------------------------------------
@@ -332,7 +342,7 @@ name prefix.
 
 =head1 AUTHOR
 
-Copyright 2003-2019, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2022, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
